Package: intergraph
Type: Package
Title: Coercion Routines for Network Data Objects
Version: 2.0-4
Authors@R: person("Michał", "Bojanowski", role=c("aut", "cre"),
	email="michal2992@gmail.com", comment=c(ORCID="0000-0001-7503-852X"))
Description: Functions implemented in this package allow to coerce (i.e.
	convert) network data between classes provided by other R packages.
	Currently supported classes are those defined in packages: network and
	igraph.
URL: https://mbojan.github.io/intergraph/
BugReports: https://github.com/mbojan/intergraph/issues
Imports: network (>= 1.4-2), igraph (>= 0.6-0), utils
Suggests: rmarkdown, knitr, roxygen2, testthat, tibble
VignetteBuilder: knitr
License: GPL-3
LazyLoad: yes
LazyData: yes
RoxygenNote: 7.3.1
Encoding: UTF-8
Depends: R (>= 2.10)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-01-30 16:05:37 UTC; mbojan
Author: Michał Bojanowski [aut, cre] (<https://orcid.org/0000-0001-7503-852X>)
Maintainer: Michał Bojanowski <michal2992@gmail.com>
Repository: CRAN
Date/Publication: 2024-02-01 17:30:02 UTC
