# Generated by roxygen2: do not edit by hand

S3method(asDF,igraph)
S3method(asDF,network)
S3method(asIgraph,data.frame)
S3method(asIgraph,network)
S3method(asNetwork,data.frame)
S3method(asNetwork,igraph)
S3method(dumpAttr,igraph)
S3method(dumpAttr,network)
S3method(igDirected,igraph)
S3method(igDirected,network)
S3method(igEcount,igraph)
S3method(igEcount,network)
S3method(igVcount,igraph)
S3method(igVcount,network)
S3method(print,netcompare)
S3method(print,netcomparea)
export(asDF)
export(asIgraph)
export(asNetwork)
export(attrmap)
export(dumpAttr)
export(netcompare)
importFrom(network,add.edges.network)
importFrom(network,as.matrix.network)
