# netcompare just works

    Code
      print(r)
    Output
      
      Identical adjacency matrices:
          TRUE 
      
      Network-level features:
               target current
      vcount   15     15     
      ecount   11     11     
      directed TRUE   TRUE   
      
      Presence of network-level attributes
        target current
      n 0      0      
      Common attributes comparison (TRUE=identical)
         No common attributes
      
      Presence of vertex-level attributes
            target current
      n     1      1      
      label TRUE   TRUE   
      Common attributes comparison (TRUE=identical)
          label : TRUE
      
      Presence of edge-level attributes
            target current
      n     1      1      
      label TRUE   TRUE   
      Common attributes comparison (TRUE=identical)
          label : TRUE

